macros.operators
================

[![Build Status](https://secure.travis-ci.org/folktale/macros.operators.png?branch=master)](https://travis-ci.org/folktale/macros.operators)
[![NPM version](https://badge.fury.io/js/macros.operators.png)](http://badge.fury.io/js/macros.operators)
[![Dependencies Status](https://david-dm.org/folktale/macros.operators.png)](https://david-dm.org/folktale/macros.operators)
[![unstable](http://badges.github.io/stability-badges/dist/unstable.svg)](http://github.com/badges/stability-badges)


Sweet.js operator macros for common operations


## Example

```js
f >>= g;          // chaining
a <*> b <*> c;    // ap
a +++ b +++ c;    // concat
a |> f; g <| a;   // piping
f ->> g; f <<- g; // function composition
```


## Installing

    $ npm install macros.operators


## Using

You can either choose to use all macros, by compiling with the root module:

```shell
sjs --module macros.operators yourfile.sjs
```

Or choose only the appropriate macros by including each one separately:

```shell
sjs --module macros.operators/macros/applicative \
    --module macros.operators/macros/functor \
    yourfile.sjs
```

## Available macros

#### `alternative.sjs`
 -  `a <|> b`: Alternative (`a.orElse(=> b)`);

#### `applicative.sjs`
 -  `a <*> b`: Applicative (`a.ap(b)`);
 -  `a <**> b`: Right-associative applicative (`b.ap(a)`);

#### `function.sjs`
 -  `a |> f`: Forward piping (`f(a)`);
 -  `f <| a`: Backward piping (`f(a)`);
 -  `f ->> g`: Forward function composition (`x => f(g(x))`);
 -  `g <<- f`: Backward function composition (`x => g(f(x))`);
 -  `a @f b, c, ...`: Infix application (`f(a, b, c, ...)`);

#### `functor.sjs`
 -  `a <$> f`: Map (`a.map(f)`);

#### `monad.sjs`
 -  `a >>= f`: Chain (`a.chain(f)`);
 -  `f =<< a`: Backward chain (`a.chain(f)`);
 -  `f >=> g`: Chain composition (`x => f(x).chain(g)`);
 -  `g <=< f`: Backward chain composition (`x => f(x).chain(g)`);

#### `monoid.sjs`
 -  `a +++ b`: Concatenation (`a.concat(b)`);

#### `proto.sjs`
 -  `a::b`: Prototype shorthand (`a.prototype.b`);


## Licence

Copyright (c) 2014 Quildreen Motta.

Released under the [MIT licence](https://github.com/folktale/macros.operators/blob/master/LICENCE).

<!-- links -->
[Fantasy Land]: https://github.com/fantasyland/fantasy-land
[Browserify]: http://browserify.org/
[Git]: http://git-scm.com/
[Make]: http://www.gnu.org/software/make/
[Node.js]: http://nodejs.org/
[es5-shim]: https://github.com/kriskowal/es5-shim
[docs]: http://folktale.github.io/macros.operators
<!-- [release: https://github.com/folktale/macros.operators/releases/download/v$VERSION/macros.operators-$VERSION.tar.gz] -->
[release]: https://github.com/folktale/macros.operators/releases/download/v0.5.1/macros.operators-0.5.1.tar.gz
<!-- [/release] -->
